WindowLayer enum

Inheritance
Available extensions

Values

background → const WindowLayer
const WindowLayer(1)
bottom → const WindowLayer
const WindowLayer(2)
top → const WindowLayer
const WindowLayer(3)
overlay → const WindowLayer
const WindowLayer(4)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
layerId → int
This is the ID of the layer. This should match with the int representation of layers in the platform side enum.
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<WindowLayer>
A constant List of the values in this enum, in order of their declaration.